import * as vscode from "vscode";
import * as lsp from "vscode-languageserver-protocol";
import { URI } from "vscode-uri";
import { TSLanguageServiceDelegate } from "../languageService";
import { CommandsShimService } from "./commands";
import { DiagnosticsShimService } from "./diagnostics";
import { WorkspaceShimService } from "./workspace";
export type ProviderRegistry<T, Args = unknown> = {
    provider: T;
    selector: vscode.DocumentSelector;
} & Args;
export type ProviderCollection<T, Args = unknown> = {
    [id: number]: ProviderRegistry<T, Args>;
};
type CodeActionProviderCollection = ProviderCollection<vscode.CodeActionProvider, {
    metadata?: vscode.CodeActionProviderMetadata;
}>;
type CompletionProviderCollection = ProviderCollection<vscode.CompletionItemProvider, {
    triggerCharacters: string[];
}>;
declare class LanguagesFeaturesRegistryService {
    private readonly diagnostics;
    private _idGen;
    private _providers;
    readonly onDidChangeDiagnostics: lsp.Event<vscode.DiagnosticChangeEvent>;
    constructor(diagnostics: DiagnosticsShimService);
    createDiagnosticCollection(name?: string): import("./diagnostics").DiagnosticCollection;
    getDiagnostics(resource: URI): vscode.Diagnostic[];
    get $providers(): {
        callHierarchy: ProviderCollection<vscode.CallHierarchyProvider, unknown>;
        codeActions: CodeActionProviderCollection;
        codeLens: ProviderCollection<vscode.CodeLensProvider<vscode.CodeLens>, unknown>;
        completionItem: CompletionProviderCollection;
        declaration: ProviderCollection<vscode.DeclarationProvider, unknown>;
        definition: ProviderCollection<vscode.DefinitionProvider, unknown>;
        documentFormattingEdit: ProviderCollection<vscode.DocumentFormattingEditProvider, unknown>;
        documentHighlight: ProviderCollection<vscode.DocumentHighlightProvider, unknown>;
        documentLink: ProviderCollection<vscode.DocumentLinkProvider<vscode.DocumentLink>, unknown>;
        documentRangeFormattignEdit: ProviderCollection<vscode.DocumentRangeFormattingEditProvider, unknown>;
        documentRangeSemanticTokens: ProviderCollection<vscode.DocumentRangeSemanticTokensProvider, unknown>;
        documentSymbol: ProviderCollection<vscode.DocumentSymbolProvider, unknown>;
        documentSemanticTokens: ProviderCollection<vscode.DocumentSemanticTokensProvider, unknown>;
        foldingRange: ProviderCollection<vscode.FoldingRangeProvider, unknown>;
        hover: ProviderCollection<vscode.HoverProvider, unknown>;
        implementation: ProviderCollection<vscode.ImplementationProvider, unknown>;
        inlayHints: ProviderCollection<vscode.InlayHintsProvider<vscode.InlayHint>, unknown>;
        onTypeFormatting: ProviderCollection<vscode.OnTypeFormattingEditProvider, {
            firstTriggerCharacter: string;
            moreTriggerCharacter: string[];
        }>;
        linkedEditingRange: ProviderCollection<vscode.LinkedEditingRangeProvider, unknown>;
        reference: ProviderCollection<vscode.ReferenceProvider, unknown>;
        rename: ProviderCollection<vscode.RenameProvider, unknown>;
        selectionRange: ProviderCollection<vscode.SelectionRangeProvider, unknown>;
        signatureHelp: ProviderCollection<vscode.SignatureHelpProvider, vscode.SignatureHelpProviderMetadata>;
        typeDefinition: ProviderCollection<vscode.TypeDefinitionProvider, unknown>;
        typeHierarchy: ProviderCollection<vscode.TypeHierarchyProvider, unknown>;
        workspaceSymbol: ProviderCollection<vscode.WorkspaceSymbolProvider<vscode.SymbolInformation>, unknown>;
    };
    private _register;
    registerCompletionItemProvider(selector: vscode.DocumentSelector, provider: vscode.CompletionItemProvider, ...triggerCharacters: string[]): lsp.Disposable;
    registerCodeActionsProvider(selector: vscode.DocumentSelector, provider: vscode.CodeActionProvider, metadata?: vscode.CodeActionProviderMetadata): lsp.Disposable;
    registerCodeLensProvider(selector: vscode.DocumentSelector, provider: vscode.CodeLensProvider): lsp.Disposable;
    registerDefinitionProvider(selector: vscode.DocumentSelector, provider: vscode.DefinitionProvider): lsp.Disposable;
    registerImplementationProvider(selector: vscode.DocumentSelector, provider: vscode.ImplementationProvider): lsp.Disposable;
    registerTypeDefinitionProvider(selector: vscode.DocumentSelector, provider: vscode.TypeDefinitionProvider): lsp.Disposable;
    registerDeclarationProvider(selector: vscode.DocumentSelector, provider: vscode.DeclarationProvider): lsp.Disposable;
    registerHoverProvider(selector: vscode.DocumentSelector, provider: vscode.HoverProvider): lsp.Disposable;
    registerDocumentHighlightProvider(selector: vscode.DocumentSelector, provider: vscode.DocumentHighlightProvider): lsp.Disposable;
    registerDocumentSymbolProvider(selector: vscode.DocumentSelector, provider: vscode.DocumentSymbolProvider): lsp.Disposable;
    registerWorkspaceSymbolProvider(provider: vscode.WorkspaceSymbolProvider): lsp.Disposable;
    registerReferenceProvider(selector: vscode.DocumentSelector, provider: vscode.ReferenceProvider): lsp.Disposable;
    registerRenameProvider(selector: vscode.DocumentSelector, provider: vscode.RenameProvider): lsp.Disposable;
    registerDocumentSemanticTokensProvider(selector: vscode.DocumentSelector, provider: vscode.DocumentSemanticTokensProvider): lsp.Disposable;
    registerDocumentRangeSemanticTokensProvider(selector: vscode.DocumentSelector, provider: vscode.DocumentRangeSemanticTokensProvider): lsp.Disposable;
    registerDocumentFormattingEditProvider(selector: vscode.DocumentSelector, provider: vscode.DocumentFormattingEditProvider): lsp.Disposable;
    registerDocumentRangeFormattingEditProvider(selector: vscode.DocumentSelector, provider: vscode.DocumentRangeFormattingEditProvider): lsp.Disposable;
    registerSignatureHelpProvider(selector: vscode.DocumentSelector, provider: vscode.SignatureHelpProvider, metadata: vscode.SignatureHelpProviderMetadata): lsp.Disposable;
    registerDocumentLinkProvider(selector: vscode.DocumentSelector, provider: vscode.DocumentLinkProvider): lsp.Disposable;
    registerInlayHintsProvider(selector: vscode.DocumentSelector, provider: vscode.InlayHintsProvider): lsp.Disposable;
    registerOnTypeFormattingEditProvider(selector: vscode.DocumentSelector, provider: vscode.OnTypeFormattingEditProvider, firstTriggerCharacter: string, ...moreTriggerCharacter: string[]): lsp.Disposable;
    registerFoldingRangeProvider(selector: vscode.DocumentSelector, provider: vscode.FoldingRangeProvider): lsp.Disposable;
    registerSelectionRangeProvider(selector: vscode.DocumentSelector, provider: vscode.SelectionRangeProvider): lsp.Disposable;
    registerCallHierarchyProvider(selector: vscode.DocumentSelector, provider: vscode.CallHierarchyProvider): lsp.Disposable;
    registerTypeHierarchyProvider(selector: vscode.DocumentSelector, provider: vscode.TypeHierarchyProvider): lsp.Disposable;
    registerLinkedEditingRangeProvider(selector: vscode.DocumentSelector, provider: vscode.LinkedEditingRangeProvider): lsp.Disposable;
    match(selector: vscode.DocumentSelector, doc: vscode.TextDocument): number;
}
export declare class LanguageFeaturesShimService extends LanguagesFeaturesRegistryService {
    private readonly delegate;
    private readonly workspace;
    private readonly commands;
    private readonly clientCapabilities;
    constructor(delegate: TSLanguageServiceDelegate, workspace: WorkspaceShimService, commands: CommandsShimService, diagnostics: DiagnosticsShimService, clientCapabilities: lsp.ClientCapabilities);
    private readonly completionCache;
    private readonly codeActionCache;
    private readonly callHierarchyCache;
    private readonly codeLensCache;
    completion(params: lsp.CompletionParams, token: lsp.CancellationToken): Promise<lsp.CompletionList>;
    completionItemResolve(item: lsp.CompletionItem, token: lsp.CancellationToken): Promise<lsp.CompletionItem>;
    documentHighlight(params: lsp.DocumentHighlightParams, token: lsp.CancellationToken): Promise<{
        range: lsp.Range;
        kind: lsp.DocumentHighlightKind;
    }[] | undefined>;
    signatureHelp(params: lsp.SignatureHelpParams, token: lsp.CancellationToken): Promise<lsp.SignatureHelp | undefined>;
    definition(params: lsp.DefinitionParams, token: lsp.CancellationToken): Promise<lsp.Location | lsp.Location[] | undefined>;
    references(params: lsp.ReferenceParams, token: lsp.CancellationToken): Promise<lsp.Location[] | undefined>;
    hover(params: lsp.HoverParams, token: lsp.CancellationToken): Promise<lsp.Hover | undefined>;
    documentSymbol(params: lsp.DocumentSymbolParams, token: lsp.CancellationToken): Promise<lsp.DocumentSymbol[] | lsp.SymbolInformation[] | undefined>;
    workspaceSymbol(params: lsp.WorkspaceSymbolParams, token: lsp.CancellationToken): Promise<lsp.SymbolInformation[] | undefined>;
    codeAction(params: lsp.CodeActionParams, token: lsp.CancellationToken): Promise<(lsp.Command | lsp.CodeAction)[] | null>;
    codeActionResolve(item: lsp.CodeAction, token: lsp.CancellationToken): Promise<lsp.CodeAction>;
    executeCommand(params: lsp.ExecuteCommandParams): Promise<any>;
    implementation(params: lsp.ImplementationParams, token: lsp.CancellationToken): Promise<lsp.Location | lsp.Location[] | undefined>;
    typeDefinition(params: lsp.TypeDefinitionParams, token: lsp.CancellationToken): Promise<lsp.Location | lsp.Location[] | undefined>;
    documentFormatting(params: lsp.DocumentFormattingParams, token: lsp.CancellationToken): Promise<lsp.TextEdit[] | undefined>;
    documentRangeFormatting(params: lsp.DocumentRangeFormattingParams, token: lsp.CancellationToken): Promise<lsp.TextEdit[] | undefined>;
    documentOnTypeFormatting(params: lsp.DocumentOnTypeFormattingParams, token: lsp.CancellationToken): Promise<lsp.TextEdit[] | undefined>;
    prepareRename(params: lsp.PrepareRenameParams, token: lsp.CancellationToken): Promise<lsp.Range | lsp.ResponseError<void> | {
        range: lsp.Range;
        placeholder: string;
    } | undefined>;
    rename(params: lsp.RenameParams, token: lsp.CancellationToken): Promise<lsp.WorkspaceEdit | undefined>;
    foldingRanges(params: lsp.FoldingRangeParams, token: lsp.CancellationToken): Promise<lsp.FoldingRange[] | undefined>;
    selectionRanges(params: lsp.SelectionRangeParams, token: lsp.CancellationToken): Promise<lsp.SelectionRange[] | undefined>;
    prepareCallHierachy(params: lsp.CallHierarchyPrepareParams, token: lsp.CancellationToken): Promise<lsp.CallHierarchyItem[] | null>;
    incomingCalls({ item }: lsp.CallHierarchyIncomingCallsParams, token: lsp.CancellationToken): Promise<lsp.CallHierarchyIncomingCall[] | null>;
    outgoingCalls({ item }: lsp.CallHierarchyOutgoingCallsParams, token: lsp.CancellationToken): Promise<lsp.CallHierarchyOutgoingCall[] | null>;
    inlayHint(params: lsp.InlayHintParams, token: lsp.CancellationToken): Promise<lsp.InlayHint[] | null>;
    codeLens(params: lsp.CodeLensParams, token: lsp.CancellationToken): Promise<lsp.CodeLens[] | undefined>;
    codeLensResolve(item: lsp.CodeLens, token: lsp.CancellationToken): Promise<lsp.CodeLens>;
    semanticTokensFull(params: lsp.SemanticTokensParams, token: lsp.CancellationToken): Promise<lsp.SemanticTokens>;
    semanticTokensRange(params: lsp.SemanticTokensRangeParams, token: lsp.CancellationToken): Promise<lsp.SemanticTokens>;
    private prepareProviderHandle;
    private prepareHighestProviderHandle;
    private getProviderWithoutSelector;
}
export {};
