import * as vscode from 'vscode';
import { CommandManager } from '../commands/commandManager';
import type * as Proto from '../protocol';
import { ITypeScriptServiceClient } from '../typescriptService';
import { DocumentSelector } from '../utils/documentSelector';
import { LanguageDescription } from '../utils/languageDescription';
import { TelemetryReporter } from '../utils/telemetry';
import TypingsStatus from '../utils/typingsStatus';
import FileConfigurationManager from './fileConfigurationManager';
interface DotAccessorContext {
    readonly range: vscode.Range;
    readonly text: string;
}
interface CompletionContext {
    readonly isNewIdentifierLocation: boolean;
    readonly isMemberCompletion: boolean;
    readonly isInValidCommitCharacterContext: boolean;
    readonly dotAccessorContext?: DotAccessorContext;
    readonly enableCallCompletions: boolean;
    readonly useCodeSnippetsOnMethodSuggest: boolean;
    readonly wordRange: vscode.Range | undefined;
    readonly line: string;
    readonly useFuzzyWordRangeLogic: boolean;
}
type ResolvedCompletionItem = {
    readonly edits?: readonly vscode.TextEdit[];
    readonly commands: readonly vscode.Command[];
};
declare class MyCompletionItem extends vscode.CompletionItem {
    readonly position: vscode.Position;
    readonly document: vscode.TextDocument;
    readonly tsEntry: Proto.CompletionEntry;
    private readonly completionContext;
    readonly metadata: any | undefined;
    readonly useCodeSnippet: boolean;
    constructor(position: vscode.Position, document: vscode.TextDocument, tsEntry: Proto.CompletionEntry, completionContext: CompletionContext, metadata: any | undefined, client: ITypeScriptServiceClient);
    private get textLabel();
    private _resolvedPromise?;
    resolveCompletionItem(client: ITypeScriptServiceClient, token: vscode.CancellationToken): Promise<ResolvedCompletionItem | undefined>;
    private getDetails;
    private getDocumentation;
    private isValidFunctionCompletionContext;
    private getCodeActions;
    private getRangeFromReplacementSpan;
    private getFilterText;
    private resolveRange;
    private getFuzzyWordRange;
    private static convertKind;
    private static getCommitCharacters;
}
export declare class TypeScriptCompletionItemProvider implements vscode.CompletionItemProvider<MyCompletionItem> {
    private readonly client;
    private readonly language;
    private readonly typingsStatus;
    private readonly fileConfigurationManager;
    private readonly telemetryReporter;
    static readonly triggerCharacters: string[];
    constructor(client: ITypeScriptServiceClient, language: LanguageDescription, typingsStatus: TypingsStatus, fileConfigurationManager: FileConfigurationManager, commandManager: CommandManager, telemetryReporter: TelemetryReporter, onCompletionAccepted: (item: vscode.CompletionItem) => void);
    provideCompletionItems(document: vscode.TextDocument, position: vscode.Position, token: vscode.CancellationToken, context: vscode.CompletionContext): Promise<vscode.CompletionList<MyCompletionItem> | undefined>;
    private logCompletionsTelemetry;
    private getTsTriggerCharacter;
    resolveCompletionItem(item: MyCompletionItem, token: vscode.CancellationToken): Promise<MyCompletionItem | undefined>;
    private isInValidCommitCharacterContext;
    private shouldTrigger;
}
export declare function register(selector: DocumentSelector, language: LanguageDescription, client: ITypeScriptServiceClient, typingsStatus: TypingsStatus, fileConfigurationManager: FileConfigurationManager, commandManager: CommandManager, telemetryReporter: TelemetryReporter, onCompletionAccepted: (item: vscode.CompletionItem) => void): vscode.Disposable;
export {};
