import * as vscode from 'vscode';
import { CommandManager } from './commands/commandManager';
import { DiagnosticKind } from './languageFeatures/diagnostics';
import FileConfigurationManager from './languageFeatures/fileConfigurationManager';
import TypeScriptServiceClient from './typescriptServiceClient';
import { Disposable } from './utils/dispose';
import { LanguageDescription } from './utils/languageDescription';
import { TelemetryReporter } from './utils/telemetry';
import TypingsStatus from './utils/typingsStatus';
export default class LanguageProvider extends Disposable {
    private readonly client;
    private readonly description;
    private readonly commandManager;
    private readonly telemetryReporter;
    private readonly typingsStatus;
    private readonly fileConfigurationManager;
    private readonly onCompletionAccepted;
    constructor(client: TypeScriptServiceClient, description: LanguageDescription, commandManager: CommandManager, telemetryReporter: TelemetryReporter, typingsStatus: TypingsStatus, fileConfigurationManager: FileConfigurationManager, onCompletionAccepted: (item: vscode.CompletionItem) => void);
    private get documentSelector();
    private registerProviders;
    private configurationChanged;
    handlesUri(resource: vscode.Uri): boolean;
    handlesDocument(doc: vscode.TextDocument): boolean;
    private handlesConfigFile;
    private get id();
    get diagnosticSource(): string;
    private updateValidate;
    private updateSuggestionDiagnostics;
    reInitialize(): void;
    triggerAllDiagnostics(): void;
    diagnosticsReceived(diagnosticsKind: DiagnosticKind, file: vscode.Uri, diagnostics: (vscode.Diagnostic & {
        reportUnnecessary: any;
        reportDeprecated: any;
    })[]): void;
    configFileDiagnosticsReceived(file: vscode.Uri, diagnostics: vscode.Diagnostic[]): void;
    private get _diagnosticLanguage();
}
